@@ -8,7 +8,7 @@ def decompose(poly):
     Decompose a polynomial to component form.
 
     In array missing values are padded with 0 to make decomposition compatible
-    with ``chaospy.sum(ouput, 0)``.
+    with ``chaospy.sum(output, 0)``.
 
     Args:
         poly (numpoly.ndpoly):
@@ -20,15 +20,15 @@ def decompose(poly):
             where ``M`` is the number of components in `poly`.
 
     Examples:
-        >>> x = numpoly.symbols()
-        >>> poly = numpoly.polynomial([x**2-1, 2])
+        >>> q0 = numpoly.variable()
+        >>> poly = numpoly.polynomial([q0**2-1, 2])
         >>> poly
-        polynomial([q**2-1, 2])
+        polynomial([q0**2-1, 2])
         >>> numpoly.decompose(poly)
         polynomial([[-1, 2],
-                    [q**2, 0]])
+                    [q0**2, 0]])
         >>> numpoly.sum(numpoly.decompose(poly), 0)
-        polynomial([q**2-1, 2])
+        polynomial([q0**2-1, 2])
 
     """
     return numpoly.concatenate([
